.. image:: https://travis-ci.org/ambitioninc/django-deletion-side-effects.png
   :target: https://travis-ci.org/ambitioninc/django-deletion-side-effects

.. image:: https://coveralls.io/repos/ambitioninc/django-deletion-side-effects/badge.png?branch=develop
    :target: https://coveralls.io/r/ambitioninc/django-deletion-side-effects?branch=develop

.. image:: https://img.shields.io/pypi/v/django-deletion-side-effects.svg
    :target: https://pypi.python.org/pypi/django-deletion-side-effects/
    :alt: Latest PyPI version

.. image:: https://img.shields.io/pypi/dm/django-deletion-side-effects.svg
    :target: https://pypi.python.org/pypi/django-deletion-side-effects/
    :alt: Number of PyPI downloads


django-deletion-side-effects
============================

Django Deletion Side Effects provides a framework for gathering side effects of deleting objects in Django.

Installation
------------
To install the latest release, type::

    pip install django-deletion-side-effects

To install the latest code directly from source, type::

    pip install git+git://github.com/ambitioninc/django-deletion-side-effects.git

Documentation
=============

Full documentation is available at http://django-deletion-side-effects.readthedocs.org

License
=======
MIT License (see LICENSE)